# Wiktionary Scraper
Wiktionary Scraper is a basic scraper implementation to get word data from Wiktionary for a given word and language.  

## Installation
You can install the Wiktionary Scraper from [PyPI](https://pypi.org/project/wkt_scraper/):
    pip install wkt_scraper
